/*
 * (c) Bernd Müller & Harald Wehr, www.jpainfo.de
 */

package de.jpainfo.test;

import java.math.BigDecimal;
import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;
import javax.persistence.Query;
import javax.persistence.TypedQuery;

import de.jpainfo.model.Konto;
import de.jpainfo.model.Kunde;

public class JPQLTest {

    public static void main(String[] args) throws Exception {
        Provider.select("hibernate");

        EntityManagerFactory emf = Persistence.createEntityManagerFactory(
                "bank", DB.h2);
        EntityManager em = emf.createEntityManager();

        Query q = em.createQuery(SUBSELECT_JPQL);

        List<Object[]> l = q.getResultList();

        OutputHelper.output(l);

        em.close();
        emf.close();
    }
    
    public static String FEHLER = " select k.nachname, k.kundennummer from Kunde k" +
    " where k.nachname = 'Meier' ";
    
    public static String INDEX = " select k.nachname, kto.kontostand from Kunde k join k.konten kto" +
    		" where index(kto) = 1 ";
    
    public static String CASE = " select case when k.kontostand < 0 THEN 'Schlecht' " +
    		" when (k.kontostand > 0 and k.kontostand <= 5000) THEN 'Gut'" +
    		" when k.kontostand > 5000 THEN 'Sehr gut' ELSE '' END as bonitaet "+
    		", k.kontostand from Konto k ";
    
    public static String TIMESTAMP = " select k.nachname, CURRENT_TIMESTAMP from Kunde k ";
    
    public static String SIZE = " select k.nachname, size(k.konten) from Kunde k ";
    
    public static String MODULO = " select mod(k.kontostand, k.kontostand), k.kontostand from Konto k ";
    
    public static String ABS = " select abs(k.kontostand), k.kontostand from Konto k ";
    
    public static String SUBSTRING = " select SUBSTRING(k.nachname,0 , 5), k.nachname from Kunde k ";
    
    public static String LOCATE = " select LOCATE('eier', k.nachname, 1 ), k.nachname from Kunde k" +
        " where LOCATE('eier', k.nachname, 1 ) > 0 ";
    
    public static String CONCAT = " select concat(k.nachname, k.vorname) from Kunde k ";
    
    public static String TYPE = " select type(k), k.nummer, k.kontostand from Konto k where type(k) = Sparkonto";

    public static String ALL_JPQL = "select giro, giro.kontostand "
            + " from Girokonto giro where giro.kontostand > ALL"
            + "  (select spar.kontostand from Sparkonto spar) ";
    
    public static String SUBSELECT_JPQL = "select kto, kto.kontostand from Konto kto "
            + " where kto.kontostand > " 
            + " (select avg(kto2.kontostand) from Konto kto2) ";


    public static String NEG_SALDO_SPAR = " select k, k.id "
            + " from Kunde k "
            + " where exists (select spar from Sparkonto spar join spar.kunden sk "
            + "       where spar.kontostand > 7000 "
            + "       and k.id = sk.id) "
            + " and exists (select giro from Girokonto giro join giro.kunden gk "
            + "       where giro.kontostand < 0 " + "       and k.id = gk.id) ";

    public static String ARRAY_DEMO = " select k, k.wohnort.ort, k.geburtsdatum from Kunde k";

    public static String ARRAY_DEMO2 = " select k, kto from Kunde k join k.konten kto where kto.kontostand < 0 ";

    public static String COUNT = "select count(k) from Konto k";

    public static String ELDEST = "  select k.geburtsdatum, k.nachname, k.vorname "
            + " from Kunde k"
            + " where k.geburtsdatum = ( select min(k2.geburtsdatum) "
            + "                          from Kunde k2 )";

    public static String RICH_AREAS = " select k.wohnort.ort, count(k), sum(kto.kontostand) "
            + " from Kunde k join k.konten kto "
            + " group by k.wohnort.ort "
            + " having count(kto) < 10 " + " and sum(kto.kontostand) > 40000 ";

    public static String ORDER_BY = "  select k, k.nachname, k.vorname "
            + " from Kunde k " + " order by k.nachname desc, k.vorname desc";

    public static String ORDER_BY_ILLEGAL = " select k.nachname, k.vorname, k.kundennummer "
            + " from Kunde k join k.konten kto "
            + "  order by kto.kontostand desc";

    public static String KUNDE_STADT = "  select new de.jpainfo.model.auswertung.KundeStadt( "
            + " k.wohnort.plz, k.wohnort.ort, count(k)) "
            + " from Kunde k"
            + " group by k.wohnort.plz, k.wohnort.ort";
    
   
    public static String LENGTH = " select LENGTH(k.nachname), k.nachname from Kunde k ";
    
    public static String COALESCE = " select COALESCE(k.nachname, k.vorname, k.geschlecht) from Kunde k ";

    public static String NULLIF = " select nullif(k.nachname, k.vorname) from Kunde k";
}
